@@ -21,7 +21,7 @@ use Encode ();
 
 use perl5i::VERSION; our $VERSION = perl5i::VERSION->VERSION;
 
-our $Latest = perl5i::VERSION->latest;
+our $Latest = 'perl5i::0';
 
 
 # This works around their lexical nature.
